@@ -32,7 +32,7 @@ class ChatAPI:
             self.log("Config successfully loaded.")
         except FileNotFoundError:
 
-            self.log(f"Config file not found at '{repr(self.config_file)}'.")
+            self.log(f"Config file not found at {repr(self.config_file)}.")
 
             self.log("Setting base config...")
             self.config = {
@@ -41,7 +41,7 @@ class ChatAPI:
                 "ErrorOnBadToken": False,
             }
 
-            self.log(f"Creating new config file at '{repr(self.config_file)}'...")
+            self.log(f"Creating new config file at {repr(self.config_file)}...")
             self.save_config()
             self.log("New config file created.")
             self.load_config()
@@ -66,6 +66,8 @@ class ChatAPI:
             self.config["ErrorOnBadToken"] = True
             self.save_config()
 
+        self.load_config()
+
         if self.token is None:
             self.log("No chat API token present in config.")
             self.get_token(
@@ -139,8 +141,13 @@ class ChatAPI:
         import json
 
         with open(self.config_file) as f:
+            if len(f.read()) == 0:
+                raise FileNotFoundError
+            else:
+                f.seek(0)
+
             self.config: dict = json.load(f)
-            self.url: dict = self.config.get("url")
+            self.url: dict = self.config.get("url", "https://www.hackmud.com")
             self.header: dict = self.config.get("header")
             self.token: str = self.config.get("chat_token")
 
